#
# spec file for package libsmdev
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}

%define lname	libsmdev1
Name:           libsmdev
Version:        20221028
Release:        3.1
Summary:        Library to access storage media devices
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libsmdev
Source:         https://github.com/libyal/libsmdev/releases/download/%version/libsmdev-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libsmdev/releases/download/%version/libsmdev-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcdata) >= 20220115
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20220107
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libuna) >= 20220611
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libsmdev is a library to access and read storage media devices.

%package -n %{lname}
Summary:        Library to access storage media devices
Group:          System/Libraries

%description -n %{lname}
libsmdev is a library to access and read storage media devices.

%package devel
Summary:        Development files for libsmdev, a storage media access library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
libsmdev is a library to access and read storage media devices.

This subpackage contains libraries and header files for developing
applications that want to make use of libsmdev.

%package tools
Summary:        Utilities for reading storage media devices through libsmdev
Group:          Productivity/File utilities

%description tools
This subpackage contains the utility programs from libsmdev, which
can access and read storage media devices and will determine
information about such.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt/"* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/libsmdev.so.1*

%files -n %name-devel
%license COPYING*
%{_includedir}/libsmdev*
%{_libdir}/libsmdev.so
%{_libdir}/pkgconfig/libsmdev.pc
%{_mandir}/man3/libsmdev.3*

%files -n %name-tools
%license COPYING*
%{_bindir}/smdevinfo
%{_mandir}/man1/smdevinfo.1*

%files %python_files
%license COPYING*
%{python_sitearch}/pysmdev.so

%changelog
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Fri Oct 28 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221028
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables Python2 on Leap 15.)
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210418 (3b84f9f7)
  * No changelog was provided
- Add system-libs.patch
* Wed Dec 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201204
  * Changes to detect removed device
- remove BuildRequires:  pkg-config
- add COPYING* to %%license line
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Wed Apr 17 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190315
  * applied updates
  * worked on tests
* Sat Feb 25 2017 Greg.Freemyer@gmail.com
- update to v0~20170225
  * applied updates
  * worked on tests
  * bug fix in debug output
- change RPM Group to Develment/Languages/Python
- review and update libyal dependencies
- add python3 binding
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20160320
  * worked on support for devices without bytes per sector support e.g. /dev/zero
  * Changes to Python bindings
  * worked on Python 3 support
  * fixes for rpmbuild
  * updated dependencies
  * block aligned read now enabled by default
- Cleaned-up BuildRequires
* Fri Jan  9 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * code clean up
  * bug fix in Python-bindings
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- ran spec-cleaner
- added BuildRequires for libcnotify and libcthreads to use the external package
- add %%doc lines to all sub-packages
- add provides pysmdev to python sub-package to match upstream requires statemens
- add "Requires:  %%lname = %%version" to python section.  Fixes a bug found in testing.
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140803
  * worked on Python bindings
  * bug fix in Python-bindings
  * updated python.m4
  * fixes for dealing with Unicode paths in pysmdev
  * fadvise bug fix
  * worked on non-blocking Windows device file support
  * worked on block-based read to support Windows device files
  * updated to include header
  * added read/write at offset functions
  * 2014 update
  * code clean up
  * updated dependencies
- use external packages for libcerror, libcdata, and libuna
- start building and packaging the python-libsmdev sub-package
* Tue Jul 30 2013 Greg.Freemyer@gmail.com
- update to v0~20130407
  * updated dependencies
  * textual changes
- change to gz compression to simplyfy download/convert
* Fri Apr  5 2013 jengelh@inai.de
- Initial package (version 0~20130331) for build.opensuse.org
